%define         debug_package %{nil}

Name:           dnscrypt-proxy
Version:        2.1.5
Release:        %mkrel 1
Summary:        A protocol for securing communications between a client and a DNS resolver
License:        BSD
Group:          Networking/Other
Url:            https://github.com/jedisct1/dnscrypt-proxy

Source0:        %{name}-%{version}.tar.gz
Source1:        %{name}.service
#socket activation is currently broken, maybe removed in the future
Source2:        %{name}.socket
Source3:        %{name}.toml

BuildRequires:  golang
BuildRequires:  pkgconfig(libsystemd)

Requires(post):  rpm-helper
Requires(preun): rpm-helper

Recommends:     unbound

%description
Dnscrypt-proxy provides local service which can be used directly as
your local resolver or as a DNS forwarder, encrypting and
authenticating requests using the DNSCrypt protocol and passing them
to an upstream server. The DNSCrypt protocol uses high-speed
high-security elliptic-curve cryptography and is very similar to
DNSCurve, but focuses on securing communications between a client and
its first-level resolver. While not providing end-to-end security, it
protects the local network, which is often the weakest point of the
chain, against man-in-the-middle attacks. It also provides some
confidentiality to DNS queries.

%prep
%setup -q


%build
export GO111MODULE=off
pushd dnscrypt-proxy
export GOPATH=$PWD
ln -s ../vendor src
go build -ldflags="-s -w"
popd

%install
pushd dnscrypt-proxy
%__install -D -p -m 0755 ./dnscrypt-proxy %{buildroot}%{_sbindir}/dnscrypt-proxy
%__install -D -p -m 0644 example-*.txt -t %{buildroot}%{_docdir}/%name/
popd
%__install -D -p -m 0644 %{SOURCE1} %{buildroot}%{_unitdir}/%{name}.service
%__install -D -p -m 0644 %{SOURCE2} %{buildroot}%{_unitdir}/%{name}.socket
%__install -D -p -m 0644 %{SOURCE3} %{buildroot}%{_sysconfdir}/%{name}.toml


%post
%_post_service %{name}

%preun
%_preun_service %{name}


%files
%doc README.md LICENSE
%config(noreplace) %{_sysconfdir}/dnscrypt-proxy.toml
%{_unitdir}/%{name}.service
%{_unitdir}/%{name}.socket
%{_sbindir}/%{name}
%{_docdir}/%{name}/*.txt


%changelog
* Sun May 05 2024 eatdirt <eatdirt> 2.1.5-1.mga10
+ Revision: 2062258
- Update to version 2.1.5

* Fri Mar 17 2023 eatdirt <eatdirt> 2.1.4-1.mga9
+ Revision: 1949606
- Update to version 2.1.4

* Fri Aug 26 2022 eatdirt <eatdirt> 2.1.2-1.mga9
+ Revision: 1880484
- Update to version 2.1.2

* Thu May 05 2022 eatdirt <eatdirt> 2.1.1-1.mga9
+ Revision: 1856355
- Upgrade to version 2.1.1

* Fri Mar 25 2022 umeabot <umeabot> 2.1.0-2.mga9
+ Revision: 1827053
- Mageia 9 Mass Rebuild

* Fri Aug 27 2021 eatdirt <eatdirt> 2.1.0-1.mga9
+ Revision: 1742896
- Upgrade to version 2.1.0

* Sat Jul 11 2020 eatdirt <eatdirt> 2.0.44-1.mga8
+ Revision: 1604346
- Upgrade to version 2.0.44
+ pterjan <pterjan>
- Remove usage of obsolete macros (https://github.com/rpm-software-management/rpm/issues/1211)

* Wed Mar 18 2020 eatdirt <eatdirt> 2.0.39-1.mga8
+ Revision: 1557863
- Upgrade to version 2.0.39

* Sat Feb 15 2020 umeabot <umeabot> 2.0.23-2.mga8
+ Revision: 1526296
- Mageia 8 Mass Rebuild

* Wed May 15 2019 eatdirt <eatdirt> 2.0.23-1.mga7
+ Revision: 1397870
- Update to version 2.0.23

* Sat Apr 06 2019 eatdirt <eatdirt> 2.0.22-1.mga7
+ Revision: 1386436
- Upgrade to version 2.0.22

* Fri Dec 14 2018 eatdirt <eatdirt> 2.0.19-1.mga7
+ Revision: 1341205
- Upgrade to version 2.0.19

* Tue Oct 09 2018 eatdirt <eatdirt> 2.0.17-1.mga7
+ Revision: 1319079
- Upgrade to version 2.0.17
+ umeabot <umeabot>
- Mageia 7 Mass Rebuild

* Wed Aug 08 2018 eatdirt <eatdirt> 2.0.16-1.mga7
+ Revision: 1250062
- Upgrade to version 2.0.16

* Mon Jul 02 2018 eatdirt <eatdirt> 2.0.15-2.mga7
+ Revision: 1241404
- Workaround to fix failure in socket activation

* Sun Jun 24 2018 eatdirt <eatdirt> 2.0.15-1.mga7
+ Revision: 1239386
- Upgrade to version 2.0.15

* Sun May 13 2018 eatdirt <eatdirt> 2.0.12-1.mga7
+ Revision: 1228985
- Upgrade to version 2.0.12

* Thu Mar 15 2018 eatdirt <eatdirt> 2.0.6-1.mga7
+ Revision: 1209591
- Upgrade to version 2.0.6

* Wed Nov 15 2017 eatdirt <eatdirt> 1.9.5-2.mga7
+ Revision: 1177494
- Rebuild for new libsodium

* Fri May 19 2017 eatdirt <eatdirt> 1.9.5-1.mga6
+ Revision: 1103438
- Upgrade to bug fix release 1.9.5

* Mon Feb 06 2017 eatdirt <eatdirt> 1.9.4-1.mga6
+ Revision: 1085002
- Upgrade to version 1.6.4

* Fri Jan 20 2017 eatdirt <eatdirt> 1.9.3-1.mga6
+ Revision: 1082501
- Upgrade to version 1.9.3

* Fri Jan 13 2017 eatdirt <eatdirt> 1.9.1-1.mga6
+ Revision: 1081498
- Upgrade to version 1.9.1

* Mon Oct 10 2016 eatdirt <eatdirt> 1.7.0-1.mga6
+ Revision: 1059960
- Upgrading dnscrypt-proxy to 1.7.0

* Tue Mar 08 2016 eatdirt <eatdirt> 1.6.1-1.mga6
+ Revision: 987413
- Upgrade to version 1.6.1

* Mon Dec 28 2015 daviddavid <daviddavid> 1.6.0-3.mga6
+ Revision: 916300
- rebuild for new sodium 1.0.8

* Sat Oct 24 2015 eatdirt <eatdirt> 1.6.0-2.mga6
+ Revision: 894951
- Add systemd working configuration files

* Tue Sep 29 2015 eatdirt <eatdirt> 1.6.0-1.mga6
+ Revision: 885212
- Upgrade to version 1.6.0

* Wed Apr 01 2015 eatdirt <eatdirt> 1.4.3-1.mga6
+ Revision: 819486
- Upgrade to version 1.4.3, support to systemd added

* Wed Oct 15 2014 umeabot <umeabot> 0.8-5.mga5
+ Revision: 745316
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0.8-4.mga5
+ Revision: 678777
- Mageia 5 Mass Rebuild

* Fri Oct 18 2013 umeabot <umeabot> 0.8-3.mga4
+ Revision: 503878
- Mageia 4 Mass Rebuild

* Fri Jan 11 2013 umeabot <umeabot> 0.8-2.mga3
+ Revision: 348903
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sat Jan 28 2012 blino <blino> 0.8-1.mga2
+ Revision: 202564
- initial package release
- Created package structure for dnscrypt-proxy.

